==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QMicrophonePermission_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtcore-config.h>
#if QT_CONFIG(permissions)
#include <QtCore/qpermissions.h>
#endif //QT_CONFIG(permissions)
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(permissions)


void deleter_QMicrophonePermission(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMicrophonePermission")
    QMicrophonePermission *_ptr = reinterpret_cast<QMicrophonePermission *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(permissions)

// emitting (writeConstructors)
// new QMicrophonePermission()
void __qt_construct_QMicrophonePermission_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMicrophonePermission()")
#if QT_CONFIG(permissions)
    Q_UNUSED(__java_arguments)
    QMicrophonePermission *__qt_this = new(__qtjambi_ptr) QMicrophonePermission();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
}

// new QMicrophonePermission(QMicrophonePermission)
void __qt_construct_QMicrophonePermission_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMicrophonePermission(QMicrophonePermission)")
#if QT_CONFIG(permissions)
    jobject other0 = __java_arguments[0].l;
    const QMicrophonePermission& __qt_other0 = qtjambi_cast<const QMicrophonePermission& >(__jni_env, other0);
    QMicrophonePermission *__qt_this = new(__qtjambi_ptr) QMicrophonePermission(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
}

// destruct QMicrophonePermission
void __qt_destruct_QMicrophonePermission(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMicrophonePermission")

#if QT_CONFIG(permissions)

    reinterpret_cast<QMicrophonePermission*>(ptr)->~QMicrophonePermission();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(permissions)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMicrophonePermission::QMicrophonePermission()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_initialize_1native__Lio_qt_core_QMicrophonePermission_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMicrophonePermission::QMicrophonePermission()")
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMicrophonePermission_0, sizeof(QMicrophonePermission), typeid(QMicrophonePermission), false, &deleter_QMicrophonePermission, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMicrophonePermission::QMicrophonePermission(QMicrophonePermission)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_initialize_1native__Lio_qt_core_QMicrophonePermission_2Lio_qt_core_QMicrophonePermission_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMicrophonePermission::QMicrophonePermission(QMicrophonePermission)")
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMicrophonePermission_1, sizeof(QMicrophonePermission), typeid(QMicrophonePermission), false, &deleter_QMicrophonePermission, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMicrophonePermission::operator=(QMicrophonePermission)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_assign_1native_1cref_1QMicrophonePermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QMicrophonePermission *__qt_this = QtJambiAPI::objectFromNativeId<QMicrophonePermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMicrophonePermission::operator=(QMicrophonePermission)", __qt_this)
        const QMicrophonePermission& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QMicrophonePermission>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMicrophonePermission::operator==(QMicrophonePermission,QMicrophonePermission)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_equals_1native_1cref_1QMicrophonePermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__2)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QMicrophonePermission *__qt_this = QtJambiAPI::objectFromNativeId<QMicrophonePermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMicrophonePermission::operator==(QMicrophonePermission,QMicrophonePermission)", __qt_this)
        const QMicrophonePermission& __qt_arg__2 = QtJambiAPI::valueReferenceFromNativeId<QMicrophonePermission>(arg__2);
        __java_return_value = (*__qt_this) == __qt_arg__2;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(arg__2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMicrophonePermission::swap(QMicrophonePermission&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_swap_1native_1ref_1QMicrophonePermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QMicrophonePermission *__qt_this = QtJambiAPI::objectFromNativeId<QMicrophonePermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMicrophonePermission::swap(QMicrophonePermission&)", __qt_this)
        QMicrophonePermission& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QMicrophonePermission>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {

#if QT_CONFIG(permissions)

        QMicrophonePermission *__qt_this = QtJambiAPI::objectFromNativeId<QMicrophonePermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(permissions)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(permissions)

        const QMicrophonePermission *__qt_this = QtJambiAPI::objectFromNativeId<QMicrophonePermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(permissions)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QMicrophonePermission(){
    using namespace RegistryAPI;

#if QT_CONFIG(permissions)

    const std::type_info& typeId = registerValueTypeInfo<QMicrophonePermission>("QMicrophonePermission", "io/qt/core/QMicrophonePermission");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QMicrophonePermission, {
        ConstructorInfo(&__qt_construct_QMicrophonePermission_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QMicrophonePermission_1, "Lio/qt/core/QMicrophonePermission;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMicrophonePermission);
    registerMetaType<QMicrophonePermission>("QMicrophonePermission");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(permissions)

}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QMicrophonePermission_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtcore-config.h>
#if QT_CONFIG(permissions)
#include <QtCore/qpermissions.h>
#endif //QT_CONFIG(permissions)
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(permissions)


void deleter_QMicrophonePermission(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMicrophonePermission")
    QMicrophonePermission *_ptr = reinterpret_cast<QMicrophonePermission *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(permissions)

// emitting (writeConstructors)
// new QMicrophonePermission()
void __qt_construct_QMicrophonePermission(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMicrophonePermission()")
#if QT_CONFIG(permissions)
    Q_UNUSED(__java_arguments)
    QMicrophonePermission *__qt_this = new(__qtjambi_ptr) QMicrophonePermission();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
}

// QMicrophonePermission::QMicrophonePermission()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_initialize_1native__Lio_qt_core_QMicrophonePermission_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMicrophonePermission::QMicrophonePermission()")
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMicrophonePermission, sizeof(QMicrophonePermission), typeid(QMicrophonePermission), false, &deleter_QMicrophonePermission, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QMicrophonePermission(QMicrophonePermission)
void __qt_construct_QMicrophonePermission_cref_QMicrophonePermission(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMicrophonePermission(QMicrophonePermission)")
#if QT_CONFIG(permissions)
    jobject other0 = __java_arguments[0].l;
    const QMicrophonePermission& __qt_other0 = qtjambi_cast<const QMicrophonePermission& >(__jni_env, other0);
    QMicrophonePermission *__qt_this = new(__qtjambi_ptr) QMicrophonePermission(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
}

// QMicrophonePermission::QMicrophonePermission(QMicrophonePermission)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_initialize_1native__Lio_qt_core_QMicrophonePermission_2Lio_qt_core_QMicrophonePermission_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMicrophonePermission::QMicrophonePermission(QMicrophonePermission)")
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMicrophonePermission_cref_QMicrophonePermission, sizeof(QMicrophonePermission), typeid(QMicrophonePermission), false, &deleter_QMicrophonePermission, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QMicrophonePermission
void __qt_destruct_QMicrophonePermission(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMicrophonePermission")

#if QT_CONFIG(permissions)

    reinterpret_cast<QMicrophonePermission*>(ptr)->~QMicrophonePermission();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(permissions)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMicrophonePermission::operator=(QMicrophonePermission)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_assign_1native_1cref_1QMicrophonePermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QMicrophonePermission *__qt_this = QtJambiAPI::objectFromNativeId<QMicrophonePermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMicrophonePermission::operator=(QMicrophonePermission)", __qt_this)
        const QMicrophonePermission& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QMicrophonePermission>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMicrophonePermission::operator==(QMicrophonePermission,QMicrophonePermission)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_equals_1native_1cref_1QMicrophonePermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__2)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QMicrophonePermission *__qt_this = QtJambiAPI::objectFromNativeId<QMicrophonePermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMicrophonePermission::operator==(QMicrophonePermission,QMicrophonePermission)", __qt_this)
        const QMicrophonePermission& __qt_arg__2 = QtJambiAPI::valueReferenceFromNativeId<QMicrophonePermission>(arg__2);
        __java_return_value = (*__qt_this) == __qt_arg__2;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(arg__2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMicrophonePermission::swap(QMicrophonePermission&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_swap_1native_1ref_1QMicrophonePermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QMicrophonePermission *__qt_this = QtJambiAPI::objectFromNativeId<QMicrophonePermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMicrophonePermission::swap(QMicrophonePermission&)", __qt_this)
        QMicrophonePermission& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QMicrophonePermission>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {

#if QT_CONFIG(permissions)

        QMicrophonePermission *__qt_this = QtJambiAPI::objectFromNativeId<QMicrophonePermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(permissions)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMicrophonePermission_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(permissions)

        const QMicrophonePermission *__qt_this = QtJambiAPI::objectFromNativeId<QMicrophonePermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(permissions)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QMicrophonePermission(){
    using namespace RegistryAPI;

#if QT_CONFIG(permissions)

    const std::type_info& typeId = registerValueTypeInfo<QMicrophonePermission>("QMicrophonePermission", "io/qt/core/QMicrophonePermission");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QMicrophonePermission, {
        ConstructorInfo(&__qt_construct_QMicrophonePermission, nullptr)
       ,ConstructorInfo(&__qt_construct_QMicrophonePermission_cref_QMicrophonePermission, "Lio/qt/core/QMicrophonePermission;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMicrophonePermission);
    registerMetaType<QMicrophonePermission>("QMicrophonePermission");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(permissions)

}
